import time

# Import the preset TestFixture.
from .Frames_capture_fixture import FixtureFramesCapture, ChannelFactory

from xtr import logging, Severity
logger = logging.getLogger(__name__)


# Create the test case class, that inherits from the preset TestFixture.
class TestCaptureEthernetPayloads(FixtureFramesCapture):

    # This method will be executed just before
    # the test case method execution.
    def setUp(self):
        logger.info("Setup test case")

    # This method will be executed just after
    # the test case method execution.
    def tearDown(self):
        logger.info("Tear down test case")

    # Create the test case method that holds the main test steps.
    def test_capture_ethernet_payloads(self):

        # Define frame properties.
        # The values provided below are arbitrary examples.
        # They do not belong to any actual in vehicle communication.
        channel_name = 'Ethernet_MTF'
        payload = [0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0x00, 0x50, 0xC2, 0xe4,
                   0x30, 0x00, 0x88, 0xB5, 0x21, 0x21, 0x54, 0x68, 0x69, 0x73,
                   0x20, 0x69, 0x73, 0x20, 0x61, 0x20, 0x64, 0x65, 0x62, 0x75,
                   0x67, 0x20, 0x66, 0x72, 0x61, 0x6d, 0x6e, 0x74, 0x20, 0x62,
                   0x79, 0x20, 0x6d, 0x74, 0x66, 0x20, 0x66, 0x72, 0x61, 0x6d,
                   0x65, 0x77]

        eth_ch = ChannelFactory().get_ethernet_channel(channel_name)

        # Start listening on the ethernet channel.
        eth_ch.listener.start_listening()

        # Log any useful message
        logger.info("Transmit an ethernet payload")

        # Transmit an ethernet payload
        eth_ch.transmitter.transmit_frame(payload)

        # Pause the program for 3 seconds.
        time.sleep(3)

        # Stop listening on the ethernet channel
        eth_ch.listener.stop_listening()

        q = eth_ch.listener.get_queue()

        # Confirm that the queue is not Null object,
        # meaning there is no error in creating the queue.
        self.assertTrue(q is not None, Severity.BLOCKER,
                        "Error when listening to the ethernet bus")

        # Confirm that queue is not empty meaning messages are received.
        self.assertTrue(len(q) >= 1, Severity.BLOCKER,
                        "Ethernet payload is not received")
